@@ -1,17 +1,11 @@
+import os
 import pickle
+import random
+import re
 
 import mdtraj
 import numpy as np
 from simtk.openmm import unit
-from shutil import copyfile
-
-
-import random
-
-from .utils import select_atoms, find_flat_bottom_radius
-
-import re
-import os
 
 from .ommtk import MetadynamicSimulation
 
